%% Neon dating software by Stephen E. Cox
% Version 1.0
% For future updates, go to www.stephenelliscox.com
% Release notes available on website
% 

function neon_dating_gui

close all;

persistent stopping;
persistent X_O;
persistent X_F;
persistent U_ppm;
persistent Uerr_ppm;
persistent Th_ppm;
persistent Therr_ppm;
persistent Ne21_pcc;
persistent Ne21err_pcc;
persistent Ne22_pcc;
persistent Ne22err_pcc;
persistent Th_U_Ratio;
persistent Th_U_Ratio_err;
persistent Ne21_He_Ratio;
persistent Ne21_He_Ratio_err;
persistent Ne22_He_Ratio;
persistent Ne22_He_Ratio_err;
persistent Method;
persistent UTh21Ne_Age;
persistent UTh21Ne_Age_err;
persistent UTh22Ne_Age;
persistent UTh22Ne_Age_err;
persistent U238_21prod;
persistent U235_21prod;
persistent Th232_21prod;
persistent U238_22prod;
persistent U235_22prod;
persistent Th232_22prod;

% assignin('base','U_ppm',10); 
% assignin('base','Th_ppm',10); 
% assignin('base','Ne21_pcc',10);
% assignin('base','Ne22_pcc',10);
% assignin('base','Th_U_Ratio',10); 
% assignin('base','Ne21_He_Ratio',10); 
% assignin('base','Ne22_He_Ratio',10); 
% assignin('base','Method',1); 
% assignin('base','UTh21Ne_Age',0);
% assignin('base','UTh22Ne_Age',0);
% assignin('base','U238_21prod',0);
% assignin('base','U235_21prod',0);
% assignin('base','Th232_21prod',0);
% assignin('base','U238_22prod',0);
% assignin('base','U235_22prod',0);
% assignin('base','Th232_22prod',0);
% stopping = load('stopping powers/Aragonite.txt');
% assignin('base','stopping',stopping);
% assignin('base','X_O',0.4795); 
% assignin('base','X_F',0); 

f = figure('Position',[0,0,1000,600]);
set(0,'defaultaxesposition',[0 0 1 1])
axis off;

%% Select mineral
text(0.05,0.97,'Select mineral:');
hpopup = uicontrol('Style','popupmenu','String',{' ','Aragonite',...
    'Baddeleyite','Calcite','Coffinite','Cryptomelane','Durango apatite','Fluorite',...
    'Goethite','Hematite','Maghemite','Magnetite','Thorianite','Thorite',...
    'Titanite','Uraninite','Xenotime-Y','Zircon'},'Position',[25,560,400,10],...
    'Callback',{@popup_menu_Callback});

set(hpopup,'FontSize',18)

%% Instruct to choose either concentrations or ratios

text(0.05,0.86,'Enter either element concentrations (first column) or element ratios (second column) and choose the corresponding Calculate button below');

%% Concentration calculations

text(0.04,0.7916,'Uranium content (ppm):');
U_control = uicontrol('Style','edit','String',' ','Position',[25,435,150,30],...
    'Callback',{@U_control_Callback});
text(0.04,0.7083,'Thorium content (ppm):');
Th_control = uicontrol('Style','edit','String',' ','Position',[25,385,150,30],...
    'Callback',{@Th_control_Callback});
text(0.04,0.6249,'Neon-21 content (pcc/g):');
Ne21_control = uicontrol('Style','edit','String',' ','Position',[25,335,150,30],...
    'Callback',{@Ne21_control_Callback});
text(0.04,0.5416,'Neon-22 content (pcc/g):');
Ne22_control = uicontrol('Style','edit','String',' ','Position',[25,285,150,30],...
    'Callback',{@Ne22_control_Callback});

text(0.2,0.7916,' (same units)');
Uerr_control = uicontrol('Style','edit','String',' ','Position',[185,435,100,30],...
    'Callback',{@Uerr_control_Callback});
Therr_control = uicontrol('Style','edit','String',' ','Position',[185,385,100,30],...
    'Callback',{@Therr_control_Callback});
Ne21err_control = uicontrol('Style','edit','String',' ','Position',[185,335,100,30],...
    'Callback',{@Ne21err_control_Callback});
Ne22err_control = uicontrol('Style','edit','String',' ','Position',[185,285,100,30],...
    'Callback',{@Ne22err_control_Callback});

set(U_control,'FontSize',14)
set(Th_control,'FontSize',14)
set(Ne21_control,'FontSize',14)
set(Ne22_control,'FontSize',14)
set(Uerr_control,'FontSize',14)
set(Therr_control,'FontSize',14)
set(Ne21err_control,'FontSize',14)
set(Ne22err_control,'FontSize',14)

Run_Conc_control = uicontrol('Style','pushbutton','String','Calculate (concentrations)','Position',[25,235,260,30],...
    'Callback',{@Run_conc_control_Callback});

set(Run_Conc_control,'FontSize',14)

function U_control_Callback(source,eventData)
    U_ppm = str2num(get(source,'String'));
    assignin('base','U_ppm',U_ppm); 
end

function Uerr_control_Callback(source,eventData)
    Uerr_ppm = str2num(get(source,'String'));
    assignin('base','Uerr_ppm',Uerr_ppm); 
end

function Th_control_Callback(source,eventData)
    Th_ppm = str2num(get(source,'String'));
    assignin('base','Th_ppm',Th_ppm); 
end

function Therr_control_Callback(source,eventData)
    Therr_ppm = str2num(get(source,'String'));
    assignin('base','Therr_ppm',Therr_ppm); 
end

function Ne21_control_Callback(source,eventData)
    Ne21_pcc = str2num(get(source,'String'));
    assignin('base','Ne21_pcc',Ne21_pcc); 
end

function Ne21err_control_Callback(source,eventData)
    Ne21err_pcc = str2num(get(source,'String'));
    assignin('base','Ne21err_pcc',Ne21err_pcc); 
end

function Ne22_control_Callback(source,eventData)
    Ne22_pcc = str2num(get(source,'String'));
    assignin('base','Ne22_pcc',Ne22_pcc); 
end

function Ne22err_control_Callback(source,eventData)
    Ne22err_pcc = str2num(get(source,'String'));
    assignin('base','Ne22err_pcc',Ne22err_pcc); 
end

function Run_conc_control_Callback(source,eventData)
    set(Age21_display,'String','Wait . . .')
    set(Age22_display,'String','Wait . . .')
    pause(0.1)    
    Method = 1;
    if Ne21_pcc > 0
    [UTh21Ne_Age,UTh21Ne_Age_err,Th232_21prod,U238_21prod,U235_21prod] = O18yield(stopping,X_O,X_F,U_ppm,Uerr_ppm,Th_ppm,Therr_ppm,Ne21_pcc,Ne21err_pcc,Ne22_pcc,Ne22err_pcc,Th_U_Ratio,Th_U_Ratio_err,Ne21_He_Ratio,Ne21_He_Ratio_err,Ne22_He_Ratio,Ne22_He_Ratio_err,Method);
    end
    if Ne22_pcc > 0
    [UTh22Ne_Age,UTh22Ne_Age_err,Th232_22prod,U238_22prod,U235_22prod] = F19yield(stopping,X_O,X_F,U_ppm,Uerr_ppm,Th_ppm,Therr_ppm,Ne21_pcc,Ne21err_pcc,Ne22_pcc,Ne22err_pcc,Th_U_Ratio,Th_U_Ratio_err,Ne21_He_Ratio,Ne21_He_Ratio_err,Ne22_He_Ratio,Ne22_He_Ratio_err,Method);
    end
    assignin('base','UTh21Ne_Age',UTh21Ne_Age);
    assignin('base','UTh22Ne_Age',UTh22Ne_Age);
    assignin('base','U238_21prod',U238_21prod);
    if isempty(UTh21Ne_Age) == 0
        set(Age21_display,'String',num2str(round(UTh21Ne_Age),'%10.5e'))
        set(Age21err_display,'String',num2str(round(UTh21Ne_Age_err),'%10.5e'))
        set(U238_21prod_disp,'String',num2str(U238_21prod))
        set(U235_21prod_disp,'String',num2str(U235_21prod))
        set(Th232_21prod_disp,'String',num2str(Th232_21prod))        
    else
        set(Age21_display,'String','No Age')
        set(Age21err_display,'String','')
        set(U238_21prod_disp,'String',num2str('N/A'))
        set(U235_21prod_disp,'String',num2str('N/A'))
        set(Th232_21prod_disp,'String',num2str('N/A'))  
    end
    if isempty(UTh22Ne_Age) == 0
        set(Age22_display,'String',num2str(round(UTh22Ne_Age),'%10.5e'))
        set(Age22err_display,'String',num2str(round(UTh22Ne_Age_err),'%10.5e'))
        set(U238_22prod_disp,'String',num2str(U238_22prod))
        set(U235_22prod_disp,'String',num2str(U235_22prod))
        set(Th232_22prod_disp,'String',num2str(Th232_22prod))  
    else
        set(Age22_display,'String','No Age')
        set(Age22err_display,'String','')
        set(U238_22prod_disp,'String',num2str('N/A'))
        set(U235_22prod_disp,'String',num2str('N/A'))
        set(Th232_22prod_disp,'String',num2str('N/A'))  
    end
end

%% Ratio calculations

text(0.315,0.7916,'Th/U ratio (by mass):');
Th_U_control = uicontrol('Style','edit','String',' ','Position',[300,435,150,30],...
    'Callback',{@Th_U_control_Callback});
text(0.315,0.7083,'^{21}Ne/He ratio (atomic):');
Ne21_He_control = uicontrol('Style','edit','String',' ','Position',[300,385,150,30],...
    'Callback',{@Ne21_He_control_Callback});
text(0.315,0.6249,'^{22}Ne/He ratio (atomic):');
Ne22_He_control = uicontrol('Style','edit','String',' ','Position',[300,335,150,30],...
    'Callback',{@Ne22_He_control_Callback});

text(0.475,0.7916,' (same units)');
Th_Uerr_control = uicontrol('Style','edit','String',' ','Position',[460,435,100,30],...
    'Callback',{@Th_Uerr_control_Callback});
Ne21_Heerr_control = uicontrol('Style','edit','String',' ','Position',[460,385,100,30],...
    'Callback',{@Ne21_Heerr_control_Callback});
Ne22_Heerr_control = uicontrol('Style','edit','String',' ','Position',[460,335,100,30],...
    'Callback',{@Ne22_Heerr_control_Callback});

Run_ratio_control = uicontrol('Style','pushbutton','String','Calculate (ratios)','Position',[300,235,260,30],...
    'Callback',{@Run_ratio_control_Callback});

set(Run_ratio_control,'FontSize',14)

function Th_U_control_Callback(source,eventData)
    Th_U_Ratio = str2num(get(source,'String'));
    assignin('base','Th_U_Ratio',Th_U_Ratio); 
end

function Ne21_He_control_Callback(source,eventData)
    Ne21_He_Ratio = str2num(get(source,'String'));
    assignin('base','Ne21_He_Ratio',Ne21_He_Ratio); 
end

function Ne22_He_control_Callback(source,eventData)
    Ne22_He_Ratio = str2num(get(source,'String'));
    assignin('base','Ne22_He_Ratio',Ne22_He_Ratio); 
end

function Th_Uerr_control_Callback(source,eventData)
    Th_U_Ratio_err = str2num(get(source,'String'));
    assignin('base','Th_U_Ratio_err',Th_U_Ratio_err); 
end

function Ne21_Heerr_control_Callback(source,eventData)
    Ne21_He_Ratio_err = str2num(get(source,'String'));
    assignin('base','Ne21_He_Ratio_err',Ne21_He_Ratio_err); 
end

function Ne22_Heerr_control_Callback(source,eventData)
    Ne22_He_Ratio_err = str2num(get(source,'String'));
    assignin('base','Ne22_He_Ratio_err',Ne22_He_Ratio_err); 
end

function Run_ratio_control_Callback(source,eventData)
    set(Age21_display,'String','Wait . . .')
    set(Age22_display,'String','Wait . . .')
    pause(0.1)
    Method = 2;
    if Ne21_He_Ratio > 0
    [UTh21Ne_Age,UTh21Ne_Age_err,Th232_21prod,U238_21prod,U235_21prod] = O18yield(stopping,X_O,X_F,U_ppm,Uerr_ppm,Th_ppm,Therr_ppm,Ne21_pcc,Ne21err_pcc,Ne22_pcc,Ne22err_pcc,Th_U_Ratio,Th_U_Ratio_err,Ne21_He_Ratio,Ne21_He_Ratio_err,Ne22_He_Ratio,Ne22_He_Ratio_err,Method);
    end
    if Ne22_He_Ratio > 0
    [UTh22Ne_Age,UTh22Ne_Age_err,Th232_22prod,U238_22prod,U235_22prod] = F19yield(stopping,X_O,X_F,U_ppm,Uerr_ppm,Th_ppm,Therr_ppm,Ne21_pcc,Ne21err_pcc,Ne22_pcc,Ne22err_pcc,Th_U_Ratio,Th_U_Ratio_err,Ne21_He_Ratio,Ne21_He_Ratio_err,Ne22_He_Ratio,Ne22_He_Ratio_err,Method);
    end
    assignin('base','UTh21Ne_Age',UTh21Ne_Age);
    assignin('base','UTh22Ne_Age',UTh22Ne_Age);
    assignin('base','U238_21prod',U238_21prod);
    if isempty(UTh21Ne_Age) == 0
        if isnumeric(UTh21Ne_Age) == 1
            set(Age21_display,'String',num2str(round(UTh21Ne_Age),'%10.5e'))
        else
            set(Age21_display,'String',UTh21Ne_Age)
        end
        set(U238_21prod_disp,'String',num2str(U238_21prod))
        set(U235_21prod_disp,'String',num2str(U235_21prod))
        set(Th232_21prod_disp,'String',num2str(Th232_21prod))
        if isnumeric(UTh21Ne_Age_err) == 1
            set(Age21err_display,'String',num2str(round(UTh21Ne_Age_err),'%10.5e'))
        else
            set(Age21err_display,'String',UTh21Ne_Age_err)
        end
    else
        set(Age21_display,'String','No Age')
        set(Age21err_display,'String','')
    end
    if isempty(UTh22Ne_Age) == 0
        if isnumeric(UTh22Ne_Age) == 1
            set(Age22_display,'String',num2str(round(UTh22Ne_Age),'%10.5e'))
        else
            set(Age22_display,'String',UTh22Ne_Age)
        end
        set(Age22_display,'String',num2str(round(UTh22Ne_Age),'%10.5e'))
        set(U238_22prod_disp,'String',num2str(U238_22prod))
        set(U235_22prod_disp,'String',num2str(U235_22prod))
        set(Th232_22prod_disp,'String',num2str(Th232_22prod))
        if isnumeric(UTh21Ne_Age_err) == 1
            set(Age22err_display,'String',num2str(round(UTh22Ne_Age_err),'%10.5e'))
        else
            set(Age22err_display,'String',UTh22Ne_Age_err)
        end
    else
        set(Age22_display,'String','No Age')
        set(Age22err_display,'String','')
    end
end

%% Age display

text(0.03125,0.31,'Neon-21 Age','FontSize',18);
text(0.03125,0.28,'(years old)','FontSize',18);
Age21_display = uicontrol('Style','edit','String','0','Position',[150,150,500,60]);
Age21err_display = uicontrol('Style','edit','String','0','Position',[660,150,300,60]);
set(Age21_display,'FontSize',30)
set(Age21err_display,'FontSize',30)

text(0.03125,0.1433,'Neon-22 Age','FontSize',18);
text(0.03125,0.1133,'(years old)','FontSize',18);
Age22_display = uicontrol('Style','edit','String','0','Position',[150,50,500,60]);
Age22err_display = uicontrol('Style','edit','String','0','Position',[660,50,300,60]);
set(Age22_display,'FontSize',30)
set(Age22err_display,'FontSize',30)

%% Production Information

text(0.6,0.7916,'Neon-21 production rates from');
text(0.6,0.7716,'each decay chain');
text(0.6,0.7516,'(ncc (STP) per decay per gram O)');
text(0.61,0.7083,'Uranium-238:');
U238_21prod_disp = uicontrol('Style','edit','String',' ','Position',[600,385,150,30]);
text(0.61,0.6249,'Uranium-235:');
U235_21prod_disp = uicontrol('Style','edit','String',' ','Position',[600,335,150,30]);
text(0.61,0.5416,'Thorium-232:');
Th232_21prod_disp = uicontrol('Style','edit','String',' ','Position',[600,285,150,30]);

set(U238_21prod_disp,'FontSize',14)
set(U235_21prod_disp,'FontSize',14)
set(Th232_21prod_disp,'FontSize',14)

text(0.78,0.7916,'Neon-22 production rates from');
text(0.78,0.7716,'each decay chain');
text(0.78,0.7516,'(ncc (STP) per decay per gram F)');
text(0.79,0.7083,'Uranium-238:');
U238_22prod_disp = uicontrol('Style','edit','String',' ','Position',[780,385,150,30]);
text(0.79,0.6249,'Uranium-235:');
U235_22prod_disp = uicontrol('Style','edit','String',' ','Position',[780,335,150,30]);
text(0.79,0.5416,'Thorium-232:');
Th232_22prod_disp = uicontrol('Style','edit','String',' ','Position',[780,285,150,30]);

set(U238_22prod_disp,'FontSize',14)
set(U235_22prod_disp,'FontSize',14)
set(Th232_22prod_disp,'FontSize',14)

%% Mineral specific information

function popup_menu_Callback(source,eventData) 
      str = get(source, 'String');
      val = get(source,'Value');
        switch str{val};
          case 'Aragonite'
             X_O = 0.4795;
             X_F = 0;
             stopping = load('stopping powers/Aragonite.txt');
             assignin('base','stopping',stopping);
          case 'Baddeleyite'
             X_O = 0.2597;
             X_F = 0;
             stopping = load('stopping powers/Baddeleyite.txt');
             assignin('base','stopping',stopping);
          case 'Barium Tungstate'             
             X_O = 0.1662;
             X_F = 0;
             stopping = load('stopping powers/Barium Tungstate.txt');
             assignin('base','stopping',stopping);             
          case 'Calcite'
             X_O = 0.4795;
             X_F = 0;
             stopping = load('stopping powers/Calcite.txt');
             assignin('base','stopping',stopping);
          case 'Coffinite'
             X_O = 0.1953;
             X_F = 0;
             stopping = load('stopping powers/Coffinite.txt');
             assignin('base','stopping',stopping);
          case 'Cryptomelane'
             X_O = 0.3485;
             X_F = 0;
             stopping = load('stopping powers/Cryptomelane.txt');
             assignin('base','stopping',stopping);
          case 'Durango apatite'
             X_O = 0.39235;
             X_F = 0.0352;
             stopping = load('stopping powers/Durango apatite.txt');
             assignin('base','stopping',stopping);
          case 'Fluorite'
             X_O = 0;
             X_F = 0.4867;
             stopping = load('stopping powers/Fluorite.txt');
             assignin('base','stopping',stopping);
          case 'Goethite'
             X_O = 0.3602;
             X_F = 0;
             stopping = load('stopping powers/Goethite.txt');
             assignin('base','stopping',stopping);
          case 'Hematite'
             X_O = 0.3006;
             X_F = 0;
             stopping = load('stopping powers/Hematite.txt');
             assignin('base','stopping',stopping);
          case 'Maghemite'
             X_O = 0.3006;
             X_F = 0;
             stopping = load('stopping powers/Maghemite.txt');
             assignin('base','stopping',stopping);
          case 'Magnetite'
             X_O = 0.2764;
             X_F = 0;
             stopping = load('stopping powers/Magnetite.txt');
             assignin('base','stopping',stopping);
          case 'Thorianite'
             X_O = 0.1212;
             X_F = 0;
             stopping = load('stopping powers/Thorianite.txt');
             assignin('base','stopping',stopping);
          case 'Thorite'
             X_O = 0.1974;
             X_F = 0;
             stopping = load('stopping powers/Thorite.txt');
             assignin('base','stopping',stopping);
          case 'Titanite'
             X_O = 0.4080;
             X_F = 0;
             stopping = load('stopping powers/Titanite.txt');
             assignin('base','stopping',stopping);
          case 'Uraninite'
             X_O = 0.1185;
             X_F = 0;
             stopping = load('stopping powers/Uraninite.txt');
             assignin('base','stopping',stopping);
          case 'Xenotime-Y'
             X_O = 0.3480;
             X_F = 0;
             stopping = load('stopping powers/Xenotime-Y.txt');
             assignin('base','stopping',stopping);
          case 'Zircon'
             X_O = 0.3491;
             X_F = 0;
             stopping = load('stopping powers/Zircon.txt');
             assignin('base','stopping',stopping);           
        end      
    assignin('base','X_O',X_O); 
    assignin('base','X_F',X_F); 
    assignin('base','stopping',stopping); 
end

set([f,hpopup],'Units','normalized');
set(f,'Name','(U-Th)/Ne')
movegui(f,'center')


end
